@@ -8,7 +8,7 @@
  * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
  * specific language governing permissions and limitations under the License.
  *
- * Copyright 2012-2024 the original author or authors.
+ * Copyright 2012-2025 the original author or authors.
  */
 package org.assertj.core.api;
 
@@ -19,6 +19,7 @@ import static java.util.stream.Collectors.toList;
 import static org.assertj.core.description.Description.mostRelevantDescription;
 import static org.assertj.core.error.ShouldMatch.shouldMatch;
 import static org.assertj.core.error.ShouldNotBeNull.shouldNotBeNull;
+import static org.assertj.core.error.ShouldNotMatch.shouldNotMatch;
 import static org.assertj.core.extractor.Extractors.byName;
 import static org.assertj.core.extractor.Extractors.extractedDescriptionOf;
 import static org.assertj.core.util.Lists.list;
@@ -30,11 +31,13 @@ import java.util.Comparator;
 import java.util.List;
 import java.util.Map;
 import java.util.Optional;
+import java.util.function.BiPredicate;
 import java.util.function.Consumer;
 import java.util.function.Function;
 import java.util.function.Predicate;
 import java.util.function.Supplier;
 
+import org.assertj.core.annotation.CheckReturnValue;
 import org.assertj.core.api.recursive.assertion.RecursiveAssertionConfiguration;
 import org.assertj.core.api.recursive.comparison.RecursiveComparisonConfiguration;
 import org.assertj.core.configuration.ConfigurationProvider;
@@ -48,19 +51,18 @@ import org.assertj.core.internal.ComparisonStrategy;
 import org.assertj.core.internal.Conditions;
 import org.assertj.core.internal.Failures;
 import org.assertj.core.internal.Objects;
+import org.assertj.core.internal.annotation.Contract;
 import org.assertj.core.presentation.PredicateDescription;
 import org.assertj.core.presentation.Representation;
-import org.assertj.core.util.CheckReturnValue;
 import org.assertj.core.util.VisibleForTesting;
 
 /**
  * Base class for all assertions.
  *
- * @param <SELF> the "self" type of this assertion class. Please read &quot;<a href="http://bit.ly/1IZIRcY"
- *          target="_blank">Emulating 'self types' using Java Generics to simplify fluent API implementation</a>&quot;
- *          for more details.
+ * @param <SELF>   the "self" type of this assertion class. Please read &quot;<a href="http://bit.ly/1IZIRcY"
+ *                 target="_blank">Emulating 'self types' using Java Generics to simplify fluent API implementation</a>&quot;
+ *                 for more details.
  * @param <ACTUAL> the type of the "actual" value.
- *
  * @author Alex Ruiz
  * @author Joel Costigliola
  * @author Mikhail Mazursky
@@ -131,10 +133,11 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
    * normally and respond appropriately.
    *
    * @param errorMessage the error message to format
-   * @param arguments the arguments referenced by the format specifiers in the errorMessage string.
+   * @param arguments    the arguments referenced by the format specifiers in the errorMessage string.
    * @see #failWithActualExpectedAndMessage(Object, Object, String, Object...)
    * @see #failure(String, Object...)
    */
+  @Contract("_, _ -> fail")
   protected void failWithMessage(String errorMessage, Object... arguments) {
     throw failure(errorMessage, arguments);
   }
@@ -163,10 +166,10 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
    * }</code></pre>
    *
    * @param errorMessage the error message to format
-   * @param arguments the arguments referenced by the format specifiers in the errorMessage string.
+   * @param arguments    the arguments referenced by the format specifiers in the errorMessage string.
+   * @return The generated assertion error.
    * @see #failureWithActualExpected(Object, Object, String, Object...)
    * @see #failWithMessage(String, Object...)
-   * @return The generated assertion error.
    */
   protected AssertionError failure(String errorMessage, Object... arguments) {
     AssertionError assertionError = Failures.instance().failureIfErrorMessageIsOverridden(info);
@@ -190,13 +193,14 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
    * preferable to using this wrapper method, as the compiler and other code analysis tools will be able to tell that the
    * statement will never return normally and respond appropriately.
    *
-   * @param actual the actual object that was found during the test
-   * @param expected the object that was expected
+   * @param actual             the actual object that was found during the test
+   * @param expected           the object that was expected
    * @param errorMessageFormat the error message to format
-   * @param arguments the arguments referenced by the format specifiers in the errorMessage string.
+   * @param arguments          the arguments referenced by the format specifiers in the errorMessage string.
    * @see #failWithMessage(String, Object...)
    * @see #failureWithActualExpected(Object, Object, String, Object...)
    */
+  @Contract("_, _, _, _ -> fail")
   protected void failWithActualExpectedAndMessage(Object actual, Object expected, String errorMessageFormat,
                                                   Object... arguments) {
     throw failureWithActualExpected(actual, expected, errorMessageFormat, arguments);
@@ -214,7 +218,7 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
    * This method also sets the "actual" and "expected" fields of the assertion if available (eg, if OpenTest4J is on the path).
    * This aids IDEs to produce visual diffs of the resulting values.
    * <p>
-   * Example :
+   * Example:
    * <pre><code class='java'> public TolkienCharacterAssert hasName(String name) {
    *   // check that actual TolkienCharacter we want to make assertions on is not null.
    *   isNotNull();
@@ -228,10 +232,10 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
    *   return this;
    * }</code></pre>
    *
-   * @param actual the actual object that was found during the test
-   * @param expected the object that was expected
+   * @param actual             the actual object that was found during the test
+   * @param expected           the object that was expected
    * @param errorMessageFormat the error message to format
-   * @param arguments the arguments referenced by the format specifiers in the errorMessage string.
+   * @param arguments          the arguments referenced by the format specifiers in the errorMessage string.
    * @return The generated assertion error.
    * @see #failure(String, Object...)
    * @see #failWithActualExpectedAndMessage(Object, Object, String, Object...)
@@ -307,7 +311,7 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
    *   &lt;"µµµ"&gt;
    * to contain:
    *   &lt;"μμμ"&gt;</code></pre>
-   *
+   * <p>
    * With Hexadecimal message:
    * <pre><code class='java'> assertThat("µµµ").inHexadecimal().contains("μμμ");
    *
@@ -343,7 +347,9 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   @CheckReturnValue
   public SELF describedAs(Description description) {
@@ -358,7 +364,9 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
     if (!descriptionText.isEmpty()) System.out.println(descriptionText);
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF isEqualTo(Object expected) {
     if (actual instanceof AbstractAssert<?, ?> && throwUnsupportedExceptionOnEquals) {
@@ -370,7 +378,9 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF isNotEqualTo(Object other) {
     if (actual instanceof AbstractAssert<?, ?> && throwUnsupportedExceptionOnEquals) {
@@ -382,114 +392,146 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public void isNull() {
     objects.assertNull(info, actual);
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF isNotNull() {
     objects.assertNotNull(info, actual);
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF isSameAs(Object expected) {
     objects.assertSame(info, actual, expected);
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF isNotSameAs(Object other) {
     objects.assertNotSame(info, actual, other);
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF isIn(Object... values) {
     objects.assertIsIn(info, actual, values);
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF isNotIn(Object... values) {
     objects.assertIsNotIn(info, actual, values);
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF isIn(Iterable<?> values) {
     objects.assertIsIn(info, actual, values);
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF isNotIn(Iterable<?> values) {
     objects.assertIsNotIn(info, actual, values);
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF is(Condition<? super ACTUAL> condition) {
     conditions.assertIs(info, actual, condition);
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF isNot(Condition<? super ACTUAL> condition) {
     conditions.assertIsNot(info, actual, condition);
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF has(Condition<? super ACTUAL> condition) {
     conditions.assertHas(info, actual, condition);
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF doesNotHave(Condition<? super ACTUAL> condition) {
     conditions.assertDoesNotHave(info, actual, condition);
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF satisfies(Condition<? super ACTUAL> condition) {
     conditions.assertSatisfies(info, actual, condition);
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @SuppressWarnings("unchecked")
   @Override
   @CheckReturnValue
   public <ASSERT extends AbstractAssert<?, ?>> ASSERT asInstanceOf(InstanceOfAssertFactory<?, ASSERT> instanceOfAssertFactory) {
     requireNonNull(instanceOfAssertFactory, shouldNotBeNull("instanceOfAssertFactory")::create);
-    objects.assertIsInstanceOf(info, actual, instanceOfAssertFactory.getType());
+    objects.assertIsInstanceOf(info, actual, instanceOfAssertFactory.getRawClass());
     return (ASSERT) instanceOfAssertFactory.createAssert(actual).withAssertionState(myself);
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF isInstanceOf(Class<?> type) {
     objects.assertIsInstanceOf(info, actual, type);
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @SuppressWarnings("unchecked")
   @Override
   public <T> SELF isInstanceOfSatisfying(Class<T> type, Consumer<T> requirements) {
@@ -499,91 +541,117 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF isInstanceOfAny(Class<?>... types) {
     objects.assertIsInstanceOfAny(info, actual, types);
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF isNotInstanceOf(Class<?> type) {
     objects.assertIsNotInstanceOf(info, actual, type);
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF isNotInstanceOfAny(Class<?>... types) {
     objects.assertIsNotInstanceOfAny(info, actual, types);
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF hasSameClassAs(Object other) {
     objects.assertHasSameClassAs(info, actual, other);
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF hasToString(String expectedToString) {
     objects.assertHasToString(info, actual, expectedToString);
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF hasToString(String expectedStringTemplate, Object... args) {
     requireNonNull(expectedStringTemplate, "The expectedStringTemplate must not be null");
     return hasToString(format(expectedStringTemplate, args));
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF doesNotHaveToString(String otherToString) {
     objects.assertDoesNotHaveToString(info, actual, otherToString);
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF doesNotHaveToString(String expectedStringTemplate, Object... args) {
     requireNonNull(expectedStringTemplate, "The expectedStringTemplate must not be null");
     return doesNotHaveToString(format(expectedStringTemplate, args));
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF doesNotHaveSameClassAs(Object other) {
     objects.assertDoesNotHaveSameClassAs(info, actual, other);
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF isExactlyInstanceOf(Class<?> type) {
     objects.assertIsExactlyInstanceOf(info, actual, type);
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF isNotExactlyInstanceOf(Class<?> type) {
     objects.assertIsNotExactlyInstanceOf(info, actual, type);
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF isOfAnyClassIn(Class<?>... types) {
     objects.assertIsOfAnyClassIn(info, actual, types);
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF isNotOfAnyClassIn(Class<?>... types) {
     objects.assertIsNotOfAnyClassIn(info, actual, types);
@@ -591,8 +659,9 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
   }
 
   /**
-   *  {@inheritDoc}
-   *  @deprecated use {@link #asInstanceOf(InstanceOfAssertFactory) asInstanceOf(InstanceOfAssertFactories.LIST)} instead
+   * {@inheritDoc}
+   *
+   * @deprecated use {@link #asInstanceOf(InstanceOfAssertFactory) asInstanceOf(InstanceOfAssertFactories.LIST)} instead
    */
   @Deprecated
   @Override
@@ -601,12 +670,14 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
     return asInstanceOf(InstanceOfAssertFactories.LIST);
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   @CheckReturnValue
   public AbstractStringAssert<?> asString() {
     objects.assertNotNull(info, actual);
-    return Assertions.assertThat(actual.toString());
+    return Assertions.assertThat(actual.toString()).withAssertionState(myself);
   }
 
   /**
@@ -628,12 +699,12 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
    * The new error message is built using {@link String#format(String, Object...)} if you provide args parameter (if you
    * don't, the error message is taken as it is).
    * <p>
-   * Example :
+   * Example:
    * <pre><code class='java'>assertThat(player.isRookie()).overridingErrorMessage(&quot;Expecting Player &lt;%s&gt; to be a rookie but was not.&quot;, player)
    *                              .isTrue();</code></pre>
    *
    * @param newErrorMessage the error message that will replace the default one provided by Assertj.
-   * @param args the args used to fill error message as in {@link String#format(String, Object...)}.
+   * @param args            the args used to fill error message as in {@link String#format(String, Object...)}.
    * @return this assertion object.
    */
   @CheckReturnValue
@@ -650,7 +721,7 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
    * You must set the message <b>before</b> calling the assertion otherwise it is ignored as the failing assertion breaks
    * the call chain by throwing an {@link AssertionError}.
    * <p>
-   * Example :
+   * Example:
    * <pre><code class='java'>assertThat(player.isRookie()).overridingErrorMessage(() -&gt; &quot;Expecting Player to be a rookie but was not.&quot;)
    *                             .isTrue();</code></pre>
    *
@@ -672,8 +743,9 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
    * Example:
    * <pre><code class='java'>assertThat(player.isRookie()).withFailMessage(&quot;Expecting Player &lt;%s&gt; to be a rookie but was not.&quot;, player)
    *                              .isTrue();</code></pre>
+   *
    * @param newErrorMessage the error message that will replace the default one provided by Assertj.
-   * @param args the args used to fill error message as in {@link String#format(String, Object...)}.
+   * @param args            the args used to fill error message as in {@link String#format(String, Object...)}.
    * @return this assertion object.
    */
   @CheckReturnValue
@@ -692,6 +764,7 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
    * Example:
    * <pre><code class='java'>assertThat(player.isRookie()).withFailMessage(() -&gt; &quot;Expecting Player to be a rookie but was not.&quot;)
    *                              .isTrue();</code></pre>
+   *
    * @param supplier the supplier supplies error message that will replace the default one provided by Assertj.
    * @return this assertion object.
    */
@@ -700,14 +773,18 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
     return overridingErrorMessage(supplier);
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   @CheckReturnValue
   public SELF usingComparator(Comparator<? super ACTUAL> customComparator) {
     return usingComparator(customComparator, null);
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   @CheckReturnValue
   public SELF usingComparator(Comparator<? super ACTUAL> customComparator, String customComparatorDescription) {
@@ -716,7 +793,27 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
+  @Override
+  @CheckReturnValue
+  public SELF usingEquals(BiPredicate<? super ACTUAL, ? super ACTUAL> predicate) {
+    return usingEquals(predicate, null);
+  }
+
+  /**
+   * {@inheritDoc}
+   */
+  @Override
+  @CheckReturnValue
+  public SELF usingEquals(BiPredicate<? super ACTUAL, ? super ACTUAL> predicate, String customEqualsDescription) {
+    return usingComparator((o1, o2) -> predicate.test(o1, o2) ? 0 : -1, customEqualsDescription);
+  }
+
+  /**
+   * {@inheritDoc}
+   */
   @Override
   @CheckReturnValue
   public SELF usingDefaultComparator() {
@@ -725,7 +822,9 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   @CheckReturnValue
   public SELF withThreadDumpOnError() {
@@ -733,7 +832,9 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   @CheckReturnValue
   public SELF withRepresentation(Representation representation) {
@@ -744,9 +845,8 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
   /**
    * {@inheritDoc}
    *
-   * @deprecated use {@link #isEqualTo} instead
-   *
    * @throws UnsupportedOperationException if this method is called.
+   * @deprecated use {@link #isEqualTo} instead
    */
   @Override
   @Deprecated
@@ -770,13 +870,12 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
   /**
    * Verifies that the actual object matches the given predicate.
    * <p>
-   * Example :
-   *
+   * Example:
    * <pre><code class='java'> assertThat(player).matches(p -&gt; p.isRookie());</code></pre>
    *
    * @param predicate the {@link Predicate} to match
    * @return {@code this} assertion object.
-   * @throws AssertionError if {@code actual} does not match the given {@link Predicate}.
+   * @throws AssertionError       if {@code actual} does not match the given {@link Predicate}.
    * @throws NullPointerException if given {@link Predicate} is null.
    */
   public SELF matches(Predicate<? super ACTUAL> predicate) {
@@ -788,20 +887,18 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
    * Verifies that the actual object matches the given predicate, the predicate description is used to get an
    * informative error message.
    * <p>
-   * Example :
-   *
+   * Example:
    * <pre><code class='java'> assertThat(player).matches(p -&gt; p.isRookie(), "is rookie");</code></pre>
-   *
-   * The error message contains the predicate description, if the previous assertion fails, it will be:
-   *
+   * <p>
+   * The error message contains the predicate description, in our example, it is:
    * <pre><code class='java'> Expecting:
    *   &lt;player&gt;
    * to match 'is rookie' predicate.</code></pre>
    *
-   * @param predicate the {@link Predicate} to match
+   * @param predicate            the {@link Predicate} to match
    * @param predicateDescription a description of the {@link Predicate} used in the error message
    * @return {@code this} assertion object.
-   * @throws AssertionError if {@code actual} does not match the given {@link Predicate}.
+   * @throws AssertionError       if {@code actual} does not match the given {@link Predicate}.
    * @throws NullPointerException if given {@link Predicate} is null.
    * @throws NullPointerException if given predicateDescription is null.
    */
@@ -809,6 +906,48 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
     return matches(predicate, new PredicateDescription(predicateDescription));
   }
 
+  /**
+   * Verifies that the actual object does not match the given predicate.
+   * <p>
+   * Example:
+   *
+   * <pre><code class='java'> assertThat(player).doesNotMatch(p -&gt; p.isRookie());</code></pre>
+   *
+   * @param predicate the {@link Predicate} not to match
+   * @return {@code this} assertion object.
+   * @throws AssertionError       if {@code actual} matches the given {@link Predicate}.
+   * @throws NullPointerException if given {@link Predicate} is null.
+   */
+  public SELF doesNotMatch(Predicate<? super ACTUAL> predicate) {
+    // use default PredicateDescription
+    return doesNotMatch(predicate, PredicateDescription.GIVEN);
+  }
+
+  /**
+   * Verifies that the actual object does not match the given predicate,
+   * the predicate description is used to get an informative error message.
+   * <p>
+   * Example:
+   *
+   * <pre><code class='java'> assertThat(player).doesNotMatch(p -&gt; p.isRookie(), "is rookie");</code></pre>
+   * <p>
+   * The error message contains the predicate description, in our example, it is:
+   *
+   * <pre><code class='java'> Expecting:
+   *   &lt;player&gt;
+   * not to match 'is rookie' predicate.</code></pre>
+   *
+   * @param predicate            the {@link Predicate} not to match
+   * @param predicateDescription a description of the {@link Predicate} used in the error message
+   * @return {@code this} assertion object.
+   * @throws AssertionError       if {@code actual} matches the given {@link Predicate}.
+   * @throws NullPointerException if given {@link Predicate} is null.
+   * @throws NullPointerException if given predicateDescription is null.
+   */
+  public SELF doesNotMatch(Predicate<? super ACTUAL> predicate, String predicateDescription) {
+    return doesNotMatch(predicate, new PredicateDescription(predicateDescription));
+  }
+
   /**
    * Verifies that the actual object satisfied the given requirements expressed as {@link Consumer}s.
    * <p>
@@ -842,7 +981,6 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
    *
    * @param requirements to assert on the actual object - must not be null.
    * @return this assertion object.
-   *
    * @throws NullPointerException if any given Consumer is null
    */
   @SafeVarargs
@@ -877,10 +1015,9 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
    *
    * @param assertions the group of assertions to run against the object under test - must not be null.
    * @return this assertion object.
-   *
    * @throws IllegalArgumentException if any given assertions group is null
-   * @throws RuntimeException rethrown as is by the given {@link ThrowingConsumer} or wrapping any {@link Throwable}.
-   * @throws AssertionError rethrown as is by the given {@link ThrowingConsumer}
+   * @throws RuntimeException         rethrown as is by the given {@link ThrowingConsumer} or wrapping any {@link Throwable}.
+   * @throws AssertionError           rethrown as is by the given {@link ThrowingConsumer}
    * @since 3.21.0
    */
   @SafeVarargs
@@ -937,7 +1074,6 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
    *
    * @param assertions the group of assertions to run against the object under test - must not be null.
    * @return this assertion object.
-   *
    * @throws IllegalArgumentException if any given assertions group is null
    * @since 3.12.0
    */
@@ -972,10 +1108,9 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
    *
    * @param assertions the group of assertions to run against the object under test - must not be null.
    * @return this assertion object.
-   *
    * @throws IllegalArgumentException if any given assertions group is null
-   * @throws RuntimeException rethrown as is by the given {@link ThrowingConsumer} or wrapping any {@link Throwable}.
-   * @throws AssertionError rethrown as is by the given {@link ThrowingConsumer}
+   * @throws RuntimeException         rethrown as is by the given {@link ThrowingConsumer} or wrapping any {@link Throwable}.
+   * @throws AssertionError           rethrown as is by the given {@link ThrowingConsumer}
    * @since 3.21.0
    */
   @SafeVarargs
@@ -1005,30 +1140,18 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
     return assertionErrorCreator.multipleAssertionsError(info.description(), assertionErrors);
   }
 
-  private boolean satisfiesAssertions(Consumer<? super ACTUAL> assertions) {
-    try {
-      assertions.accept(actual);
-    } catch (@SuppressWarnings("unused") AssertionError e) {
-      return false;
-    }
-    return true;
-  }
-
-  private AssertionError catchAssertionError(Consumer<? super ACTUAL> assertions) {
-    try {
-      assertions.accept(actual);
-    } catch (AssertionError assertionError) {
-      return assertionError;
-    }
-    throw new IllegalStateException("Shouldn't arrived here, assertions should have raised an AssertionError (please file a bug)");
-  }
-
   private SELF matches(Predicate<? super ACTUAL> predicate, PredicateDescription predicateDescription) {
     requireNonNull(predicate, "The predicate must not be null");
     if (predicate.test(actual)) return myself;
     throw Failures.instance().failure(info, shouldMatch(actual, predicate, predicateDescription));
   }
 
+  private SELF doesNotMatch(Predicate<? super ACTUAL> predicate, PredicateDescription predicateDescription) {
+    requireNonNull(predicate, "The predicate must not be null");
+    if (predicate.negate().test(actual)) return myself;
+    throw Failures.instance().failure(info, shouldNotMatch(actual, predicate, predicateDescription));
+  }
+
   public static void setCustomRepresentation(Representation customRepresentation) {
     ConfigurationProvider.loadRegisteredConfiguration();
     AbstractAssert.customRepresentation = customRepresentation;
@@ -1043,14 +1166,18 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
     AbstractAssert.descriptionConsumer = descriptionConsumer;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF hasSameHashCodeAs(Object other) {
     objects.assertHasSameHashCodeAs(info, actual, other);
     return myself;
   }
 
-  /** {@inheritDoc} */
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public SELF doesNotHaveSameHashCodeAs(Object other) {
     objects.assertDoesNotHaveSameHashCodeAs(info, actual, other);
@@ -1062,7 +1189,7 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
    * <p>
    * this method avoids code duplication when features like extracting/asList need to create a new list assertions.
    *
-   * @param <E> the type of elements.
+   * @param <E>       the type of elements.
    * @param newActual new list under test
    * @return a new {@link AbstractListAssert}.
    */
@@ -1091,7 +1218,7 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
   // this method is meant to be overridden and made public in subclasses that want to expose it
   // this would avoid duplicating this code in all subclasses
   protected RecursiveComparisonAssert<?> usingRecursiveComparison() {
-    return usingRecursiveComparison(new RecursiveComparisonConfiguration());
+    return usingRecursiveComparison(new RecursiveComparisonConfiguration(info.representation()));
   }
 
   // this method is meant to be overridden and made public in subclasses that want to expose it
@@ -1122,10 +1249,9 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
    * @param assertFactory   the factory for the creation of the new {@code Assert}
    * @return the new {@code Assert} instance
    * @throws AssertionError if {@code actual} is {@code null}
-   *
-   * @since 3.16.0
    * @see AbstractObjectAssert#extracting(String)
    * @see AbstractObjectAssert#extracting(String, InstanceOfAssertFactory)
+   * @since 3.16.0
    */
   @SuppressWarnings("unchecked")
   @CheckReturnValue
@@ -1150,10 +1276,9 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
    * @param assertFactory the factory for the creation of the new {@code Assert}
    * @return the new {@code Assert} instance
    * @throws AssertionError if {@code actual} is {@code null}
-   *
-   * @since 3.16.0
    * @see AbstractObjectAssert#extracting(Function)
    * @see AbstractObjectAssert#extracting(Function, InstanceOfAssertFactory)
+   * @since 3.16.0
    */
   @SuppressWarnings("unchecked")
   @CheckReturnValue
@@ -1170,10 +1295,9 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
    * Returns true if actual and other are equal according to the current comparison strategy.
    *
    * @param actual the object to compare to other
-   * @param other the object to compare to actual
+   * @param other  the object to compare to actual
    * @return true if actual and other are equal according to the underlying comparison strategy.
    * @since 3.23.0
-   *
    * @deprecated {@link ComparisonStrategy} will become part of the public API in the next major release and this method
    * will be removed.
    */
@@ -1181,4 +1305,29 @@ public abstract class AbstractAssert<SELF extends AbstractAssert<SELF, ACTUAL>,
   protected boolean areEqual(Object actual, Object other) {
     return objects.getComparisonStrategy().areEqual(actual, other);
   }
+
+  /**
+   * Returns actual (the object currently under test).
+   * <p>
+   * This can be useful if after chaining assertions, the object under test has changed and you want to get it.
+   * <p>
+   * Examples of method changing actual:
+   * {@link AbstractObjectAssert#extracting(Function) extracting(Function)} or a navigation methods like
+   * {@link AbstractThrowableAssert#rootCause() rootCause()}.
+   * <p>
+   * Example:
+   * <pre><code class='java'> TolkienCharacter frodo = TolkienCharacter.of("Frodo", 33, HOBBIT);
+   *
+   * String newActual = assertThat(frodo).extracting(TolkienCharacter::getName).actual();
+   *
+   * // newActual == frodo.getName()
+   * assertThat(newActual).isSameAs(frodo.name);</code></pre>
+   *
+   * @return actual the object currently under test.
+   * @since 3.27.0
+   */
+  public ACTUAL actual() {
+    return actual;
+  }
+
 }
