@@ -8,7 +8,7 @@
  * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
  * specific language governing permissions and limitations under the License.
  *
- * Copyright 2012-2024 the original author or authors.
+ * Copyright 2012-2025 the original author or authors.
  */
 package org.assertj.core.api;
 
@@ -29,6 +29,7 @@ import java.time.LocalTime;
 import java.time.OffsetDateTime;
 import java.time.OffsetTime;
 import java.time.Period;
+import java.time.YearMonth;
 import java.time.ZonedDateTime;
 import java.util.Date;
 import java.util.Iterator;
@@ -65,9 +66,9 @@ import java.util.stream.IntStream;
 import java.util.stream.LongStream;
 import java.util.stream.Stream;
 
+import org.assertj.core.annotation.CheckReturnValue;
 import org.assertj.core.api.ThrowableAssert.ThrowingCallable;
 import org.assertj.core.configuration.PreferredAssumptionException;
-import org.assertj.core.util.CheckReturnValue;
 
 /**
  * A unified entry point to all assumptions from both the new Java 8 core API and the pre-Java 8 core API.
@@ -986,6 +987,17 @@ public interface WithAssumptions {
     return Assumptions.assumeThat(localDate);
   }
 
+  /**
+   * Creates a new instance of <code>{@link YearMonthAssert}</code> assumption.
+   *
+   * @param yearMonth the actual value.
+   * @return the created assumption for assertion object.
+   * @since 3.26.0
+   */
+  default AbstractYearMonthAssert<?> assumeThat(final YearMonth yearMonth) {
+    return Assumptions.assumeThat(yearMonth);
+  }
+
   /**
    * Creates a new instance of <code>{@link LocalTimeAssert}</code> assumption.
    *
