@@ -8,7 +8,7 @@
  * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
  * specific language governing permissions and limitations under the License.
  *
- * Copyright 2012-2024 the original author or authors.
+ * Copyright 2012-2025 the original author or authors.
  */
 package org.assertj.core.api;
 
@@ -18,7 +18,7 @@ public class ConcreteIterableAssert<ELEMENT> extends
     FactoryBasedNavigableIterableAssert<ConcreteIterableAssert<ELEMENT>, Iterable<ELEMENT>, ELEMENT, ObjectAssert<ELEMENT>> {
 
   public ConcreteIterableAssert(Collection<ELEMENT> actual) {
-    super(actual, ConcreteIterableAssert.class, new ObjectAssertFactory<>());
+    super(actual, ConcreteIterableAssert.class, ObjectAssert::new);
   }
 
   @Override
