@@ -8,11 +8,11 @@
  * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
  * specific language governing permissions and limitations under the License.
  *
- * Copyright 2012-2024 the original author or authors.
+ * Copyright 2012-2025 the original author or authors.
  */
 package org.assertj.core.api;
 
-import static org.assertj.core.test.FloatArrays.emptyArray;
+import static org.assertj.core.testkit.FloatArrays.emptyArray;
 import static org.mockito.Mockito.mock;
 
 import org.assertj.core.internal.FloatArrays;
