@@ -8,7 +8,7 @@
  * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
  * specific language governing permissions and limitations under the License.
  *
- * Copyright 2012-2024 the original author or authors.
+ * Copyright 2012-2025 the original author or authors.
  */
 package org.assertj.core.api;
 
@@ -17,7 +17,7 @@ import static org.mockito.Mockito.mock;
 import java.util.Spliterator;
 
 import org.assertj.core.internal.Spliterators;
-import org.assertj.core.test.StringSpliterator;
+import org.assertj.core.testkit.StringSpliterator;
 
 public abstract class SpliteratorAssertBaseTest extends BaseTestTemplate<SpliteratorAssert<String>, Spliterator<String>> {
 
