@@ -8,13 +8,13 @@
  * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
  * specific language governing permissions and limitations under the License.
  *
- * Copyright 2012-2024 the original author or authors.
+ * Copyright 2012-2025 the original author or authors.
  */
 package org.assertj.core.api.filter;
 
 import static org.assertj.core.api.filter.Filters.filter;
 
-import org.assertj.core.test.Player;
+import org.assertj.core.testkit.Player;
 
 class Filter_with_property_equals_to_given_value_short_version_Test extends AbstractTest_equals_filter {
 
