@@ -8,7 +8,7 @@
  * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
  * specific language governing permissions and limitations under the License.
  *
- * Copyright 2012-2024 the original author or authors.
+ * Copyright 2012-2025 the original author or authors.
  */
 package org.assertj.core.api.map;
 
@@ -19,7 +19,7 @@ import java.util.Map;
 
 import org.assertj.core.api.MapAssert;
 import org.assertj.core.api.MapAssertBaseTest;
-import org.assertj.core.test.Maps;
+import org.assertj.core.testkit.Maps;
 
 /**
  * Tests for <code>{@link org.assertj.core.api.MapAssert#hasSameSizeAs(java.util.Map)}</code>.
