@@ -8,7 +8,7 @@
  * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
  * specific language governing permissions and limitations under the License.
  *
- * Copyright 2012-2024 the original author or authors.
+ * Copyright 2012-2025 the original author or authors.
  */
 package org.assertj.core.error;
 
@@ -35,8 +35,8 @@ import org.assertj.core.internal.DeepDifference.Difference;
 import org.assertj.core.internal.objects.Objects_assertIsEqualToComparingFieldByFieldRecursive_Test.WithCollection;
 import org.assertj.core.internal.objects.Objects_assertIsEqualToComparingFieldByFieldRecursive_Test.WithMap;
 import org.assertj.core.presentation.Representation;
-import org.assertj.core.test.Jedi;
-import org.assertj.core.test.Name;
+import org.assertj.core.testkit.Jedi;
+import org.assertj.core.testkit.Name;
 import org.junit.jupiter.api.Test;
 
 class ShouldBeEqualByComparingFieldByFieldRecursively_create_Test {
@@ -225,6 +225,7 @@ class ShouldBeEqualByComparingFieldByFieldRecursively_create_Test {
                                    "field/property 'last' differ:%n" +
                                    "- actual value  : \"Johnson\"%n" +
                                    "- expected value: \"Ginobili\"%n" +
+                                   "Compared objects have java types and were thus compared with equals method%n" +
                                    "%n" +
                                    "The recursive comparison was performed with this configuration:%n%s",
                                    CONFIGURATION_PROVIDER.representation().toStringOf(recursiveComparisonConfiguration)));
